@@ -32,9 +32,8 @@ from yubico_client.py3 import urlencode
 
 logger = logging.getLogger('yubico.client')
 
-# Path to the custom CA certificates bundle. Only used if set.
-CA_CERTS_BUNDLE_PATH = None
-
+# Path to the standard CA bundle file locations for most of the operating
+# systems
 COMMON_CA_LOCATIONS = [
     '/usr/local/lib/ssl/certs/ca-certificates.crt',
     '/usr/local/ssl/certs/ca-certificates.crt',
@@ -55,11 +54,11 @@ COMMON_CA_LOCATIONS = [
     'C:\Windows\cacert.pem'
 ]
 
-DEFAULT_API_URLS = ('api.yubico.com/wsapi/2.0/verify',
-                    'api2.yubico.com/wsapi/2.0/verify',
-                    'api3.yubico.com/wsapi/2.0/verify',
-                    'api4.yubico.com/wsapi/2.0/verify',
-                    'api5.yubico.com/wsapi/2.0/verify')
+DEFAULT_API_URLS = ('https://api.yubico.com/wsapi/2.0/verify',
+                    'https://api2.yubico.com/wsapi/2.0/verify',
+                    'https://api3.yubico.com/wsapi/2.0/verify',
+                    'https://api4.yubico.com/wsapi/2.0/verify',
+                    'https://api5.yubico.com/wsapi/2.0/verify')
 
 DEFAULT_TIMEOUT = 10            # How long to wait before the time out occurs
 DEFAULT_MAX_TIME_WINDOW = 5     # How many seconds can pass between the first
@@ -73,13 +72,21 @@ BAD_STATUS_CODES = ['BAD_OTP', 'REPLAYED_OTP', 'BAD_SIGNATURE',
 
 
 class Yubico(object):
-    def __init__(self, client_id, key=None, use_https=True, verify_cert=True,
-                 translate_otp=True, api_urls=DEFAULT_API_URLS):
+    def __init__(self, client_id, key=None, verify_cert=True,
+                 translate_otp=True, api_urls=DEFAULT_API_URLS,
+                 ca_certs_bundle_path=None):
+
+        if ca_certs_bundle_path and \
+           not self._is_valid_ca_bundle_file(ca_certs_bundle_path):
+            raise ValueError(('Invalid value provided for ca_certs_bundle_path'
+                             ' argument'))
+
         self.client_id = client_id
         self.key = base64.b64decode(key) if key is not None else None
         self.verify_cert = verify_cert
         self.translate_otp = translate_otp
-        self.api_urls = self._init_request_urls(api_urls, use_https)
+        self.api_urls = self._init_request_urls(api_urls=api_urls)
+        self.ca_certs_bundle_path = ca_certs_bundle_path
 
     def verify(self, otp, timestamp=False, sl=None, timeout=None,
                return_response=False):
@@ -198,7 +205,7 @@ class Yubico(object):
                             'be older than the last one')
 
         if delta > max_time_window:
-            raise Exception(('More then %s seconds has passed between '
+            raise Exception(('More than %s seconds have passed between '
                             'generating the first and the last OTP.') %
                             (max_time_window))
 
@@ -340,7 +347,7 @@ class Yubico(object):
                            in query_string.split('&')])
         return dictionary
 
-    def _init_request_urls(self, api_urls, use_https=True):
+    def _init_request_urls(self, api_urls):
         """
         Returns a list of the API URLs.
         """
@@ -350,32 +357,35 @@ class Yubico(object):
         if isinstance(api_urls, str):
             api_urls = (api_urls,)
 
-        urls = []
-        for url in api_urls:
-            if not url.startswith('http'):
-                if use_https:
-                    url = 'https://%s' % (url)
-                else:
-                    url = 'http://%s' % (url)
-            urls.append(url)
+        api_urls = list(api_urls)
 
-        return urls
+        for url in api_urls:
+            if not url.startswith('http://') and \
+               not url.startswith('https://'):
+                raise ValueError(('URL "%s" contains an invalid or missing'
+                                 ' scheme' % (url)))
+
+        return list(api_urls)
 
     def _get_ca_bundle_path(self):
         """
         Return a path to the CA bundle which is used for verifying the hosts
         SSL certificate.
         """
-        if CA_CERTS_BUNDLE_PATH:
+        if self.ca_certs_bundle_path:
             # User provided a custom path
-            return CA_CERTS_BUNDLE_PATH
+            return self.ca_certs_bundle_path
 
+        # Return first bundle which is available
         for file_path in COMMON_CA_LOCATIONS:
-            if os.path.exists(file_path) and os.path.isfile(file_path):
+            if self._is_valid_ca_bundle_file(file_path=file_path):
                 return file_path
 
         return None
 
+    def _is_valid_ca_bundle_file(self, file_path):
+        return os.path.exists(file_path) and os.path.isfile(file_path)
+
 
 class URLThread(threading.Thread):
     def __init__(self, url, timeout, verify_cert, ca_bundle_path=None):
